summaryrefslogtreecommitdiffstats
path: root/domino/domino.h
diff options
context:
space:
mode:
Diffstat (limited to 'domino/domino.h')
-rw-r--r--domino/domino.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/domino/domino.h b/domino/domino.h
index 9142482..115748e 100644
--- a/domino/domino.h
+++ b/domino/domino.h
@@ -21,7 +21,7 @@
Copyright (C) 2000 Daniel M. Duley <[email protected]>
(C) 2000 Dirk Mueller <[email protected]>
(C) 2001 Martijn Klingens <[email protected]>
- Progressbar code based on KStyle,
+ Progressbar code based on TDEStyle,
Copyright (C) 2001-2002 Karol Szwed <[email protected]>
This library is free software; you can redistribute it and/or
@@ -41,9 +41,9 @@
#ifndef __DOMINO_H
#define __DOMINO_H
-#include <kstyle.h>
+#include <tdestyle.h>
#include <tqintcache.h>
-#include <ktoolbarbutton.h>
+#include <tdetoolbarbutton.h>
#include "misc.h"
#include "data.h"
#include <tqpixmapcache.h>
@@ -92,7 +92,7 @@ class Rubber;
};
-class DominoStyle : public KStyle
+class DominoStyle : public TDEStyle
{
Q_OBJECT
@@ -113,7 +113,7 @@ public:
void polish( TQPalette &p );
void unPolish(TQWidget* widget );
- void drawKStylePrimitive(KStylePrimitive kpe,
+ void drawTDEStylePrimitive(TDEStylePrimitive kpe,
TQPainter* p,
const TQWidget* widget,
const TQRect &r,
@@ -334,7 +334,7 @@ protected:
bool mouseOver = false,
bool horizontal = true,
bool enabled = true,
- bool khtmlMode = false) const;
+ bool tdehtmlMode = false) const;
void renderHeader(TQPainter *p,
const TQRect &r,
@@ -397,7 +397,7 @@ protected:
TQPixmap* popupFrame;
TQPixmap* border1;
mutable bool alphaButtonMode;
- bool KApplicationMode;
+ bool TDEApplicationMode;
TQColor _checkMarkColor;
TQMap<const TQGroupBox*, const TQPixmap*> groupBoxPixmaps;
@@ -407,7 +407,7 @@ protected:
TQPoint popupMousePressPos;
protected slots:
- void khtmlWidgetDestroyed(TQObject* w);
+ void tdehtmlWidgetDestroyed(TQObject* w);
void groupBoxDestroyed(TQObject* w);
//Animation slots.
@@ -470,8 +470,8 @@ private:
bool hoveredToolBoxTab;
- // track khtml widgets.
- TQMap<const TQWidget*,bool> khtmlWidgets;
+ // track tdehtml widgets.
+ TQMap<const TQWidget*,bool> tdehtmlWidgets;
//Animation support.
TQMap<TQWidget*, int> progAnimWidgets;
@@ -817,11 +817,11 @@ class DominoTQWhatsThat : public TQWidget
TQString text;
};
-class DominoKToolBarButton : public KToolBarButton
+class DominoKToolBarButton : public TDEToolBarButton
{
friend class DominoStyle;
public:
- DominoKToolBarButton(): KToolBarButton() {}
+ DominoKToolBarButton(): TDEToolBarButton() {}
};
class DominoTQListBoxItem : public TQListBoxItem